__title__ = 'FinDataBroker'
__description__ = 'A databroker for financial data'
__url__ = 'https://github.com/tomerten/findatabroker'
__version__ = '1.0.0alpha4'
__author__ = 'Tom Mertens'
__license__ = 'GNU General Public License v3.0'